**Example 1: 验证自定义多因子Token**



Input: 

```
tccli cam ConsumeCustomMFAToken --cli-unfold-argument  \
    --MFAToken abc123
```

Output: 
```
{
    "Response": {
        "RequestId": "f8914327-5a9f-4016-8b2e-00f8b8901121"
    }
}
```

